@@ -5,6 +5,7 @@ import math
 from os import path
 from copy import deepcopy
 import json
+import re
 
 from ._schema_common import (
     PRIMITIVES,
@@ -19,6 +20,8 @@ from ._schema_common import (
     rabin_fingerprint,
 )
 
+SYMBOL_REGEX = re.compile(r"[A-Za-z_][A-Za-z0-9_]*")
+
 
 def extract_record_type(schema):
     if isinstance(schema, dict):
@@ -344,6 +347,8 @@ def _parse_schema(schema, namespace, expand, _write_hint, names, named_schemas):
                 raise SchemaParseException(f"redefined named type: {fullname}")
             names.add(fullname)
 
+            _validate_enum_symbols(schema["symbols"])
+
             named_schemas[fullname] = parsed_schema
 
             parsed_schema["name"] = fullname
@@ -772,3 +777,13 @@ def fingerprint(parsing_canonical_form, algorithm):
 
     h = hashlib.new(algorithm, parsing_canonical_form.encode())
     return h.hexdigest()
+
+
+def _validate_enum_symbols(symbols):
+    for symbol in symbols:
+        if not isinstance(symbol, str) or not re.match(SYMBOL_REGEX, symbol):
+            raise SchemaParseException(
+                "Every symbol must match the regular expression [A-Za-z_][A-Za-z0-9_]*"
+            )
+    if len(symbols) != len(set(symbols)):
+        raise SchemaParseException("All symbols in an enum must be unique")
